@@ -74,25 +74,29 @@ class File:
         """Returns existing file content"""
 
         f = None
+        t = None
+
         if self.encode != None:
             # t = f.read().decode(self.encode)
             f = open(self.fileName, "rb")
             t = f.read()
+            f.close()
 
             # with open(self.fileName, "rb") as binary_file:
             #     # Read the whole file at once
             #     f = binary_file.read()
 
-
             # with open(self.fileName, "rb") as f:
             #     byte = f.read(1)
             #         while byte:
             #         # Do stuff with byte.
             #         byte = f.read(1)
+
         else:
             f = open(self.fileName)
             t = f.read()
-        f.close
+            f.close()
+        # f.close
         return t
 
     def print(self):
